# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_lobbymatchmaking.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_lobbymatchmaking.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$steammessages_lobbymatchmaking.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x9e\x01\n-LobbyMatchmakingLegacy_GetLobbyStatus_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x15\n\rsteamid_lobby\x18\x02 \x01(\x06\x12\x17\n\x0f\x63laim_ownership\x18\x03 \x01(\x08\x12\x18\n\x10\x63laim_membership\x18\x04 \x01(\x08\x12\x13\n\x0bversion_num\x18\x05 \x01(\r\"\x93\x01\n.LobbyMatchmakingLegacy_GetLobbyStatus_Response\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x15\n\rsteamid_lobby\x18\x02 \x01(\x06\x12:\n\x0clobby_status\x18\x03 \x01(\x0e\x32\r.ELobbyStatus:\x15k_ELobbyStatusInvalid*\x81\x01\n\x0c\x45LobbyStatus\x12\x19\n\x15k_ELobbyStatusInvalid\x10\x00\x12\x18\n\x14k_ELobbyStatusExists\x10\x01\x12\x1e\n\x1ak_ELobbyStatusDoesNotExist\x10\x02\x12\x1c\n\x18k_ELobbyStatusNotAMember\x10\x03\x32\xc6\x01\n\x16LobbyMatchmakingLegacy\x12\x85\x01\n\x0eGetLobbyStatus\x12..LobbyMatchmakingLegacy_GetLobbyStatus_Request\x1a/.LobbyMatchmakingLegacy_GetLobbyStatus_Response\"\x12\x82\xb5\x18\x0eGetLobbyStatus\x1a$\x82\xb5\x18 Lobby matchmaking legacy serviceB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])

_ELOBBYSTATUS = _descriptor.EnumDescriptor(
  name='ELobbyStatus',
  full_name='ELobbyStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ELobbyStatusInvalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ELobbyStatusExists', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ELobbyStatusDoesNotExist', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ELobbyStatusNotAMember', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=412,
  serialized_end=541,
)
_sym_db.RegisterEnumDescriptor(_ELOBBYSTATUS)

ELobbyStatus = enum_type_wrapper.EnumTypeWrapper(_ELOBBYSTATUS)
k_ELobbyStatusInvalid = 0
k_ELobbyStatusExists = 1
k_ELobbyStatusDoesNotExist = 2
k_ELobbyStatusNotAMember = 3



_LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_REQUEST = _descriptor.Descriptor(
  name='LobbyMatchmakingLegacy_GetLobbyStatus_Request',
  full_name='LobbyMatchmakingLegacy_GetLobbyStatus_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='LobbyMatchmakingLegacy_GetLobbyStatus_Request.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_lobby', full_name='LobbyMatchmakingLegacy_GetLobbyStatus_Request.steamid_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claim_ownership', full_name='LobbyMatchmakingLegacy_GetLobbyStatus_Request.claim_ownership', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claim_membership', full_name='LobbyMatchmakingLegacy_GetLobbyStatus_Request.claim_membership', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_num', full_name='LobbyMatchmakingLegacy_GetLobbyStatus_Request.version_num', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=259,
)


_LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_RESPONSE = _descriptor.Descriptor(
  name='LobbyMatchmakingLegacy_GetLobbyStatus_Response',
  full_name='LobbyMatchmakingLegacy_GetLobbyStatus_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='LobbyMatchmakingLegacy_GetLobbyStatus_Response.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_lobby', full_name='LobbyMatchmakingLegacy_GetLobbyStatus_Response.steamid_lobby', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lobby_status', full_name='LobbyMatchmakingLegacy_GetLobbyStatus_Response.lobby_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=409,
)

_LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_RESPONSE.fields_by_name['lobby_status'].enum_type = _ELOBBYSTATUS
DESCRIPTOR.message_types_by_name['LobbyMatchmakingLegacy_GetLobbyStatus_Request'] = _LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_REQUEST
DESCRIPTOR.message_types_by_name['LobbyMatchmakingLegacy_GetLobbyStatus_Response'] = _LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_RESPONSE
DESCRIPTOR.enum_types_by_name['ELobbyStatus'] = _ELOBBYSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LobbyMatchmakingLegacy_GetLobbyStatus_Request = _reflection.GeneratedProtocolMessageType('LobbyMatchmakingLegacy_GetLobbyStatus_Request', (_message.Message,), {
  'DESCRIPTOR' : _LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_REQUEST,
  '__module__' : 'steammessages_lobbymatchmaking_pb2'
  # @@protoc_insertion_point(class_scope:LobbyMatchmakingLegacy_GetLobbyStatus_Request)
  })
_sym_db.RegisterMessage(LobbyMatchmakingLegacy_GetLobbyStatus_Request)

LobbyMatchmakingLegacy_GetLobbyStatus_Response = _reflection.GeneratedProtocolMessageType('LobbyMatchmakingLegacy_GetLobbyStatus_Response', (_message.Message,), {
  'DESCRIPTOR' : _LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_RESPONSE,
  '__module__' : 'steammessages_lobbymatchmaking_pb2'
  # @@protoc_insertion_point(class_scope:LobbyMatchmakingLegacy_GetLobbyStatus_Response)
  })
_sym_db.RegisterMessage(LobbyMatchmakingLegacy_GetLobbyStatus_Response)


DESCRIPTOR._options = None

_LOBBYMATCHMAKINGLEGACY = _descriptor.ServiceDescriptor(
  name='LobbyMatchmakingLegacy',
  full_name='LobbyMatchmakingLegacy',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030 Lobby matchmaking legacy service',
  create_key=_descriptor._internal_create_key,
  serialized_start=544,
  serialized_end=742,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLobbyStatus',
    full_name='LobbyMatchmakingLegacy.GetLobbyStatus',
    index=0,
    containing_service=None,
    input_type=_LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_REQUEST,
    output_type=_LOBBYMATCHMAKINGLEGACY_GETLOBBYSTATUS_RESPONSE,
    serialized_options=b'\202\265\030\016GetLobbyStatus',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOBBYMATCHMAKINGLEGACY)

DESCRIPTOR.services_by_name['LobbyMatchmakingLegacy'] = _LOBBYMATCHMAKINGLEGACY

LobbyMatchmakingLegacy = service_reflection.GeneratedServiceType('LobbyMatchmakingLegacy', (_service.Service,), dict(
  DESCRIPTOR = _LOBBYMATCHMAKINGLEGACY,
  __module__ = 'steammessages_lobbymatchmaking_pb2'
  ))

LobbyMatchmakingLegacy_Stub = service_reflection.GeneratedServiceStubType('LobbyMatchmakingLegacy_Stub', (LobbyMatchmakingLegacy,), dict(
  DESCRIPTOR = _LOBBYMATCHMAKINGLEGACY,
  __module__ = 'steammessages_lobbymatchmaking_pb2'
  ))


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='gc.proto',
  package='foobar',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x08gc.proto\x12\x06\x66oobar\"\xe8\x02\n\x12\x43MsgProtoBufHeader\x12\x17\n\x0f\x63lient_steam_id\x18\x01 \x01(\x06\x12\x19\n\x11\x63lient_session_id\x18\x02 \x01(\x05\x12\x15\n\rsource_app_id\x18\x03 \x01(\r\x12+\n\rjob_id_source\x18\n \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12+\n\rjob_id_target\x18\x0b \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12\x17\n\x0ftarget_job_name\x18\x0c \x01(\t\x12\x12\n\x07\x65result\x18\r \x01(\x05:\x01\x32\x12\x15\n\rerror_message\x18\x0e \x01(\t\x12K\n\ngc_msg_src\x18\xc8\x01 \x01(\x0e\x32\x18.foobar.GCProtoBufMsgSrc:\x1cGCProtoBufMsgSrc_Unspecified\x12\x1c\n\x13gc_dir_index_source\x18\xc9\x01 \x01(\r*\xb6\x01\n\x10GCProtoBufMsgSrc\x12 \n\x1cGCProtoBufMsgSrc_Unspecified\x10\x00\x12\x1f\n\x1bGCProtoBufMsgSrc_FromSystem\x10\x01\x12 \n\x1cGCProtoBufMsgSrc_FromSteamID\x10\x02\x12\x1b\n\x17GCProtoBufMsgSrc_FromGC\x10\x03\x12 \n\x1cGCProtoBufMsgSrc_ReplySystem\x10\x04'
)

_GCPROTOBUFMSGSRC = _descriptor.EnumDescriptor(
  name='GCProtoBufMsgSrc',
  full_name='foobar.GCProtoBufMsgSrc',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GCProtoBufMsgSrc_Unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GCProtoBufMsgSrc_FromSystem', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GCProtoBufMsgSrc_FromSteamID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GCProtoBufMsgSrc_FromGC', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GCProtoBufMsgSrc_ReplySystem', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=384,
  serialized_end=566,
)
_sym_db.RegisterEnumDescriptor(_GCPROTOBUFMSGSRC)

GCProtoBufMsgSrc = enum_type_wrapper.EnumTypeWrapper(_GCPROTOBUFMSGSRC)
GCProtoBufMsgSrc_Unspecified = 0
GCProtoBufMsgSrc_FromSystem = 1
GCProtoBufMsgSrc_FromSteamID = 2
GCProtoBufMsgSrc_FromGC = 3
GCProtoBufMsgSrc_ReplySystem = 4



_CMSGPROTOBUFHEADER = _descriptor.Descriptor(
  name='CMsgProtoBufHeader',
  full_name='foobar.CMsgProtoBufHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_steam_id', full_name='foobar.CMsgProtoBufHeader.client_steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_session_id', full_name='foobar.CMsgProtoBufHeader.client_session_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_app_id', full_name='foobar.CMsgProtoBufHeader.source_app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id_source', full_name='foobar.CMsgProtoBufHeader.job_id_source', index=3,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=True, default_value=18446744073709551615,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id_target', full_name='foobar.CMsgProtoBufHeader.job_id_target', index=4,
      number=11, type=6, cpp_type=4, label=1,
      has_default_value=True, default_value=18446744073709551615,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_job_name', full_name='foobar.CMsgProtoBufHeader.target_job_name', index=5,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='foobar.CMsgProtoBufHeader.eresult', index=6,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='foobar.CMsgProtoBufHeader.error_message', index=7,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gc_msg_src', full_name='foobar.CMsgProtoBufHeader.gc_msg_src', index=8,
      number=200, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gc_dir_index_source', full_name='foobar.CMsgProtoBufHeader.gc_dir_index_source', index=9,
      number=201, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21,
  serialized_end=381,
)

_CMSGPROTOBUFHEADER.fields_by_name['gc_msg_src'].enum_type = _GCPROTOBUFMSGSRC
DESCRIPTOR.message_types_by_name['CMsgProtoBufHeader'] = _CMSGPROTOBUFHEADER
DESCRIPTOR.enum_types_by_name['GCProtoBufMsgSrc'] = _GCPROTOBUFMSGSRC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgProtoBufHeader = _reflection.GeneratedProtocolMessageType('CMsgProtoBufHeader', (_message.Message,), {
  'DESCRIPTOR' : _CMSGPROTOBUFHEADER,
  '__module__' : 'gc_pb2'
  # @@protoc_insertion_point(class_scope:foobar.CMsgProtoBufHeader)
  })
_sym_db.RegisterMessage(CMsgProtoBufHeader)


# @@protoc_insertion_point(module_scope)
